==> kdevelop_5.2.1.orig.tar.xz: kdevelop-5.2.1/plugins/custom-definesandincludes/compilerprovider/compilerfactories.h <==
/*
 * This file is part of KDevelop
 *
 * Copyright 2014 Sergey Kalinichev <kalinichev.so.0@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef COMPILERFACTORIES_H
#define COMPILERFACTORIES_H

#include "icompilerfactory.h"

class ClangFactory : public ICompilerFactory
{
public:
    CompilerPointer createCompiler( const QString& name, const QString& path, bool editable = true ) const override;

    QString name() const override;

    void registerDefaultCompilers(CompilerProvider* provider) const override;
};

class GccFactory : public ICompilerFactory
{
public:
    CompilerPointer createCompiler( const QString& name, const QString& path, bool editable = true ) const override;

    QString name() const override;

    void registerDefaultCompilers(CompilerProvider* provider) const override;
};

class MsvcFactory : public ICompilerFactory
{
public:
    CompilerPointer createCompiler( const QString& name, const QString& path, bool editable = true ) const override;

    QString name() const override;

    void registerDefaultCompilers(CompilerProvider* provider) const override;
};

#endif // COMPILERFACTORIES_H

==> kdevelop_5.6.2.orig.tar.xz: kdevelop-5.6.2/plugins/custom-definesandincludes/compilerprovider/compilerfactories.h <==
/*
 * This file is part of KDevelop
 *
 * Copyright 2014 Sergey Kalinichev <kalinichev.so.0@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef COMPILERFACTORIES_H
#define COMPILERFACTORIES_H

#include "icompilerfactory.h"

class ClangFactory : public ICompilerFactory
{
public:
    CompilerPointer createCompiler( const QString& name, const QString& path, bool editable = true ) const override;

    QString name() const override;
    bool isSupported(const KDevelop::Path& path) const override;

    void registerDefaultCompilers(CompilerProvider* provider) const override;
};

class GccFactory : public ICompilerFactory
{
public:
    CompilerPointer createCompiler( const QString& name, const QString& path, bool editable = true ) const override;

    QString name() const override;
    bool isSupported(const KDevelop::Path& path) const override;

    void registerDefaultCompilers(CompilerProvider* provider) const override;
};

class MsvcFactory : public ICompilerFactory
{
public:
    CompilerPointer createCompiler( const QString& name, const QString& path, bool editable = true ) const override;

    QString name() const override;
    bool isSupported(const KDevelop::Path& path) const override;

    void registerDefaultCompilers(CompilerProvider* provider) const override;
};

#endif // COMPILERFACTORIES_H
